;+
; CUBEOBJECT::FINDCROSSINGS
;
; Intent:
;        Find places where Bx = By = 0 using contours on each surface
;        Add them to QCP (if appropriate)
;
; History:
;        CB, October 2006
;-

pro cubeObject::findCrossings, top=top, bottom=bottom, left=left, $
              right = right, front = front, back = back

self -> getPlanes, top=top, bottom=bottom, left=left, $
                   right = right, front = front, back = back, $
                   xplane = xplane, yplane = yplane

y = findgen(n_elements(xplane[0,*]))
x = findgen(n_elements(xplane[*,0]))

contour, xplane, path_xy = xxy, path_info = pix, lev = [0], closed = 0, /path_data, x, y
contour, yplane, path_xy = yxy, path_info = piy, lev = [0], closed = 0, /path_data, x, y
;stop
if n_elements(pix) * n_elements(piy) eq 0 then return

xc = contours2curves(xxy, pix)
yc = contours2curves(yxy, piy)

ncross = findCrossings(xc, yc, cp=cp)

if ncross eq 0 then return

cp = self->revertToBoxCoords(cp,  top=top, bottom=bottom, left=left, $
                             right = right, front = front, back = back, $
                             ncross = ncross)

self->addQCPs, cp


end
